Stan Math Library: stan::math::container_view< dummy, T2 > Class Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | Public Member Functions | List of all members
stan::math::container_view< dummy, T2 > Class Template Reference

Dummy type specialization, used in conjunction with struct dummy as described above. More...

`#include <container_view.hpp>`

## Public Types
typedef stan::scalar_type< T2 >::type | scalar_t

## Public Member Functions
template<typename T1 >
| container_view (const T1 &x, scalar_t *y)
| Nothing initialized. More...
scalar_t | operator[] (int n) const
| operator[](int i) throws exception More...

## Detailed Description

### template<typename T2>
class stan::math::container_view< dummy, T2 >

Dummy type specialization, used in conjunction with struct dummy as described above.

Template Parameters

  T2 | type of scalar returned by view

Definition at line 63 of file container_view.hpp.

## Member Typedef Documentation

template<typename T2 >

typedef stan::scalar_type<T2>::type stan::math::container_view< dummy, T2 >::scalar_t

Definition at line 65 of file container_view.hpp.

## Constructor & Destructor Documentation

template<typename T2 >
template<typename T1 >

stan::math::container_view< dummy, T2 >::container_view | ( | const T1 & | x,
|  | scalar_t * | y
| ) |  |
| inline

Nothing initialized.

Parameters

  x | input object
  y | underlying array

Definition at line 74 of file container_view.hpp.

## Member Function Documentation

template<typename T2 >

scalar_t stan::math::container_view< dummy, T2 >::operator[] | ( | int | n | ) | const
| inline

operator[](int i) throws exception

Parameters

  n | index

Definition at line 82 of file container_view.hpp.

The documentation for this class was generated from the following file:

- stan/math/prim/scal/meta/container_view.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.